.. kayobe documentation master file, created by
   sphinx-quickstart on Tue Jul  9 22:26:36 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

==================================
Welcome to Kayobe's documentation!
==================================

Overview
========

Welcome to the Kayobe documentation, the official source of information for
understanding and using Kayobe.

This documentation is maintained at opendev.org
`here <https://opendev.org/openstack/kayobe.git>`_. Feedback and contributions
welcome, see :doc:`contributing <contributor/contributing>` for information on
how.

Kayobe
======

.. include:: ../../README.rst
   :start-line: 6

Contents
========

.. toctree::
   :maxdepth: 2

   getting-started
   architecture
   support-matrix
   installation
   usage
   configuration/index
   deployment
   upgrading
   administration/index
   resources

Advanced Documentation
----------------------

.. toctree::
   :maxdepth: 2

   control-plane-service-placement
   custom-ansible-playbooks
   multiple-environments

Contributor Guide
-----------------

.. toctree::
   :maxdepth: 2

   contributor/index
